@@ -12,6 +12,7 @@ from typing import TYPE_CHECKING, Any, Callable, Dict, List, Optional, Union
 
 import packaging
 import subprocess_tee
+from packaging.version import Version
 
 from ansible_compat.config import (
     AnsibleConfig,
@@ -25,7 +26,7 @@ from ansible_compat.errors import (
     InvalidPrerequisiteError,
     MissingAnsibleError,
 )
-from ansible_compat.loaders import yaml_from_file
+from ansible_compat.loaders import colpath_from_path, yaml_from_file
 from ansible_compat.prerun import get_cache_dir
 
 if TYPE_CHECKING:
@@ -36,6 +37,8 @@ else:
     CompletedProcess = subprocess.CompletedProcess
 
 _logger = logging.getLogger(__name__)
+# regex to extract the first version from a collection range specifier
+version_re = re.compile(":[>=<]*([^,]*)")
 
 
 class Runtime:
@@ -79,6 +82,15 @@ class Runtime:
         self.isolated = isolated
         self.max_retries = max_retries
         self.environ = environ or os.environ.copy()
+        # Reduce noise from paramiko, unless user already defined PYTHONWARNINGS
+        # paramiko/transport.py:236: CryptographyDeprecationWarning: Blowfish has been deprecated
+        # https://github.com/paramiko/paramiko/issues/2038
+        # As CryptographyDeprecationWarning is not a builtin, we cannot use
+        # PYTHONWARNINGS to ignore it using category but we can use message.
+        # https://stackoverflow.com/q/68251969/99834
+        if "PYTHONWARNINGS" not in self.environ:
+            self.environ["PYTHONWARNINGS"] = "ignore:Blowfish has been deprecated"
+
         if isolated:
             self.cache_dir = get_cache_dir(self.project_dir)
         self.config = AnsibleConfig()
@@ -207,6 +219,13 @@ class Runtime:
         if force or self.version_in_range(upper="2.11"):
             cmd.append("--force")
 
+        # As ansible-galaxy install is not able to automatically determine
+        # if the range requires a pre-release, we need to manuall add the --pre
+        # flag when needed.
+        matches = version_re.search(collection)
+        if matches and Version(matches[1]).is_prerelease:
+            cmd.append("--pre")
+
         if destination:
             cmd.extend(["-p", str(destination)])
         cmd.append(f"{collection}")
@@ -296,7 +315,7 @@ class Runtime:
                 _logger.error(run.stdout)
                 raise AnsibleCommandError(run)
 
-    def prepare_environment(
+    def prepare_environment(  # noqa: C901
         self,
         required_collections: Optional[Dict[str, str]] = None,
         retry: bool = False,
@@ -333,6 +352,21 @@ class Runtime:
             return
 
         if os.path.exists("galaxy.yml"):
+            if destination:
+                # while function can return None, that would not break the logic
+                colpath = f"{destination}/ansible_collections/{colpath_from_path(os.getcwd())}"
+                if os.path.islink(colpath):
+                    if os.path.realpath(colpath) == os.getcwd():
+                        _logger.warning(
+                            "Found symlinked collection, skipping its installation."
+                        )
+                        return
+                    _logger.warning(
+                        "Collection is symlinked, but not pointing to %s directory, so we will remove it.",
+                        os.getcwd(),
+                    )
+                    os.unlink(colpath)
+
             # molecule scenario within a collection
             self.install_collection_from_disk(".", destination=destination)
         elif pathlib.Path().resolve().parent.name == "roles" and os.path.exists(
@@ -404,7 +438,7 @@ class Runtime:
                 break
         else:
             if install:
-                self.install_collection(f"{name}:>={version}")
+                self.install_collection(f"{name}:>={version}" if version else name)
                 self.require_collection(name=name, version=version, install=False)
             else:
                 msg = f"Collection '{name}' not found in '{paths}'"
